equalsTo method
Returns true if the internals of Set and others are compared and match.
Returns true if both itself and others are null.
Setとothersの内部を比較して一致している場合trueを返します。
自身とothersが両方ともNullな場合trueを返します。
Implementation
bool equalsTo(Set<T>? others) {
if (this == null && others != null) {
return false;
}
if (this != null && others == null) {
return false;
}
if (this == null && others == null) {
return true;
}
return this!.equalsTo(others);
}